#include "max11131.h"

//####################################################################################################################################################################################
//                                                                       MAX11131_SPI_init()
//
// Initialisiert die SPI-Schnittstelle fr Kanal UCA1 des MSP430F5359
//
void MAX11131_SPI_init(void)
{
  P8SEL |= BIT1 + BIT2 + BIT3;                                                   // Spezialfunktion;    Pins MAX11131-SCK, -MOSI, -MISO
  P8DIR |= BIT0 + BIT1 + BIT2;                                                   // Richtung;           Pins MAX11131-CS, -SCK, -MOSI Ausgnge, sonst Eingnge
  P8OUT |= BIT0 + BIT2;                                                          // Low/High, Pull-Up?; Pins MAX11131-CS, -MOSI auf "High", sonst "Low"
  P8REN |= BIT3;                                                                 // PullU-D Aktivieren; Pull-Downs MAX11131-MISO

  UCA1CTL1 |= UCSWRST;                                                           // "Neustart" der SPI
  UCA1CTL0 |= UCMST+UCSYNC+UCCKPL+/*UCCKPH+*/UCMSB;                              // SPI master 3-pin & MSB, Synchronus, Inactive High, 8-bit
  UCA1CTL1 |= UCSSEL_2;                                                          // = SMCLK = F_CPU = 32,7MHz
  UCA1BR0 = 2;                                                                   // Frequenz von SPI auf etwa 16,3MHz (f=F_CPU / 2) gesetzt.Der AD-Wandler soll bis 48MHZ knnen ...
  UCA1BR1 = 0;                                                                   // .-
  UCA1MCTL = 0;                                                                  // Keine Modulation
  UCA1CTL1 &= ~UCSWRST;                                                          // Aktiviere USART **Initialize USCI state machine**
  //UCA1IE |= UCRXIE;                                                            // Aktiviere USCI_A1 RX interrupt

  for(int i=50;i>0;i--);                                                         // Gebe den Slave (MCP3208) etwas zeit

  while (!(UCA1IFG&UCTXIFG));                                                    // Warte bis TX-Puffer bereit ist
  UCA1TXBUF = 0x00;                                                              // Sende einen Dummy
}

//####################################################################################################################################################################################
//                                                                       MAX11131_SPI_transmit()
//
// Senden und empfangen ber SPI ber Kanal UCA1 des MSP430F5359
//
unsigned char MAX11131_SPI_transmit(unsigned char data)
{   
  while (!(UCA1IFG & UCTXIFG));                                                  // USCI_A1 TX buffer ready?
  UCA1TXBUF = data;                                                              // Sende
  while(UCA1STAT & UCBUSY);
  
  //while (!(UCA1IFG & UCRXIFG));                                                // USCI_A1 TX buffer ready?
  data = UCA1RXBUF;                                                              // Sende
  while(UCA1STAT & UCBUSY);                                                      // Warte bis Nachricht vollsrndig ist
  
  return data;
} 

//####################################################################################################################################################################################
//                                                                       MAX11131_transmit()
//
// Sendet und Empfngt zum und vom MAX11131 ber die SPI-Schnittstelle. Die !CS-Funktion zum signalisieren eines Frames ist hier schon drin. Fr die Befehle siehe die Defines und Da-
// tenblatt ab Seite 15. Beachte es wird ein 2 Byte Befehl gesendet. Je nach Befehl wird auch geantwortet. Die Antwort muss aber der letzen Befehl der Versand wurde zugeordnet werden 
// und nicht den aktuellen der Versand wird.-
//
// @ command = Befehl der dem MAX11131 versandt werden soll
// 
// @ return  = Antwort die vom MAX11131 verhalten wurde
//
unsigned int MAX11131_transmit(unsigned int command)
{ 
  MAX11131_CS_LOW;
  
  // Bekomme Info als Low- und High-Byte
  char low, high;
  high  = MAX11131_SPI_transmit((char)((command & 0xFF00) >> 8));                // High Byte Senden
  low = MAX11131_SPI_transmit((char)(command & 0x00FF));                         // Low Byte Senden  
  
  // Das High Byte besteht aus (4 Bit Kanal + ersten 4 Bit AD-Werte)
  char kanal = (high & 0xF0) >> 4;                                               // Trenne die HEX-Zahl entsprechend
  high = high & 0x0F;
  
  unsigned int info = ((high << 8) | low); 

  MAX11131_CS_HIGH;
   
  if(info == kanal) return info;
  return info;
}

//####################################################################################################################################################################################
//                                                                  MAX11131_bipolar_chanel()
//
// Funktion sollte nur intern genutzt werden. Switch-Anweisung zur Auswahl  des Bipolar-Kanals 
//
// @ k      = Kanal der ausgewhlt werden soll
//
// @ return = Gibt das entsprechende Register zurck
//
unsigned int MAX11131_bipolar_chanel(char k)
{
  switch(k)
  {
    case 0: return MAX11131_BCH00_01;
    case 1: return MAX11131_BCH02_03;
    case 2: return MAX11131_BCH04_05;
    case 3: return MAX11131_BCH06_07;
    case 4: return MAX11131_BCH08_09;
    case 5: return MAX11131_BCH10_11;
    case 6: return MAX11131_BCH12_13;
    case 7: return MAX11131_BCH14_15;
    
    default: return 0;
  } // switch
}

//####################################################################################################################################################################################
//                                                                 MAX11131_range_chanel()
//
// Funktion sollte nur intern genutzt werden. Switch-Anweisung zur Auswahl  des Range-Kanals
//
// @ k      = Kanal der ausgewhlt werden soll
//
// @ return = Gibt das entsprechende Register zurck
//
unsigned int MAX11131_range_chanel(char k)
{
  switch(k)
  {
    case 0: return MAX11131_RAN00_01;
    case 1: return MAX11131_RAN02_03;
    case 2: return MAX11131_RAN04_05;
    case 3: return MAX11131_RAN06_07;
    case 4: return MAX11131_RAN08_09;
    case 5: return MAX11131_RAN10_11;
    case 6: return MAX11131_RAN12_13;
    case 7: return MAX11131_RAN14_15;
    
    default: return 0;
  } // switch
}

//####################################################################################################################################################################################
//                                                                   MAX11131_unipolar_chanel()
//
// Funktion sollte nur intern genutzt werden. Switch-Anweisung zur Auswahl  des Unipolar-Kanals
//
// @ k      = Kanal der ausgewhlt werden soll
//
// @ return = Gibt das entsprechende Register zurck
//
unsigned int MAX11131_unipolar_chanel(char k)
{
  switch(k)
  {
    case 0: return MAX11131_UCH00_01;
    case 1: return MAX11131_UCH02_03;
    case 2: return MAX11131_UCH04_05;
    case 3: return MAX11131_UCH06_07;
    case 4: return MAX11131_UCH08_09;
    case 5: return MAX11131_UCH10_11;
    case 6: return MAX11131_UCH12_13;
    case 7: return MAX11131_UCH14_15;
    
    default: return 0;
  } // switch
}

//####################################################################################################################################################################################
//                                                                   MAX11131_csel_chanel()
//
// Funktion sollte nur intern genutzt werden. Switch-Anweisung zur Auswahl der AD-Kanle
//
// @ k      = Kanal der ausgewhlt werden soll
//
// @ return = Gibt das entsprechende Register zurck
//
unsigned int MAX11131_csel_chanel(char k)
{ 
  switch(k)
  {
    case 0: return  MAX11131_CSEL00;
    case 1: return  MAX11131_CSEL01;
    case 2: return  MAX11131_CSEL02;
    case 3: return  MAX11131_CSEL03;
    case 4: return  MAX11131_CSEL04;
    case 5: return  MAX11131_CSEL05;
    case 6: return  MAX11131_CSEL06;
    case 7: return  MAX11131_CSEL07;
    case 8: return  MAX11131_CSEL08;
    case 9: return  MAX11131_CSEL09;
    case 10: return MAX11131_CSEL10;
    case 11: return MAX11131_CSEL11;
    case 12: return MAX11131_CSEL12;
    case 13: return MAX11131_CSEL13;
    case 14: return MAX11131_CSEL14;
    case 15: return MAX11131_CSEL15;
    
    default: return 0;
  } // switch
}

//####################################################################################################################################################################################
//                                                                   MAX11131_Echo_aktiv()
//
// Aktiviert die Echo-Funktion des MAX11131 fr die Konfig-Register. Hierbei: Aktiviere-Echo -> Sende neue Konfig zur Zeit t -> Sende wieder neue Konfig zur Zeit t+1 und bekomme als 
// Echo von MISO die Konfig aus Zeit t. Usw...
//
void MAX11131_Echo_aktiv (char status)
{
    if(status == TRUE) MAX11131_transmit(MAX11131_ADC_CONF | MAX11131_ECHO);   
    else MAX11131_transmit(MAX11131_ADC_CONF | !(MAX11131_ECHO));
}

//####################################################################################################################################################################################
//                                                                       MAX11131_test()
//
// Teste den MAX11131 indem ich einen Echo sende und daraufhin eine Konfig, als Resultat sollte 0x8380 kommen
//
void MAX11131_test (void)
{
  MAX11131_CS_LOW;   
  MAX11131_Echo_aktiv (TRUE);
  MAX11131_CS_HIGH;
  __delay_cycles(10000);

  MAX11131_CS_LOW; 
  MAX11131_transmit(MAX11131_ADC_CONF | MAX11131_AVGON | MAX11131_NAVG32);
  MAX11131_CS_HIGH;
  __delay_cycles(10000);
}


//####################################################################################################################################################################################
//                                                                     MAX11131_ADC_conf()
//
// Setze den MAX11131 ADC-Config Register.
//
// Variable GLOBAL in der Header zu finden und gegebenfalls bearbeiten (wahl zwischen TRUE oder FALSE)
// @ RefSel = TRUE: Single-Ebded Referenz    ; FALSE: Differentiele Referenz
// @ SoP_FD = TRUE: Pseudo oder Single-Ended ; FALSE: Voll-Differenziell
// @ SinEnd = TRUE: Single-Ended             ; FALSE: Pseudo-Differenziell
// @ UniBip = TRUE: Unipolar                 ; FALSE: Bipolar
// @ ran    = TRUE: Referenz +/-Vref         ; Referenz +/-Vref/2            ; Nur bei Bipolar von Interesse
// @ anz    = Anzahl der Kanle, whle zwischen 0 bis 7
//
void MAX11131_ADC_conf(void)
{
  unsigned int befehl = 0x0000;
  
  // -------- 1. Referenzspannung auswhlen  fr den IC -----------------------------------------------
  
  befehl = MAX11131_ADC_CONF;                                                    // MAX11131_ADC_CONF gehe zum ADC Config Register
      
  if(MAX11131_RefSel == TRUE)                                                    // Single Ended
  {
    befehl = befehl | !MAX11131_REFSEL;                                          // !MAX11131_REFSEL lsche Pin fr Single-Ended 
    MAX11131_transmit(befehl);                                                   // Sende nun den Befehl
    __delay_cycles(1000);                                                        // Warte etwas als Sicherheit
  } // if (RefSel)
  
  else                                                                           // Oder Voll Differentiel
  {
    befehl = befehl | MAX11131_REFSEL;                                           // MAX11131_REFSEL setze Pin fr Differenziel
    MAX11131_transmit(befehl);                                                   // Sende nun den Befehl
    __delay_cycles(1000);                                                        // Warte etwas als Sicherheitv
  } // else (RefSel)
  
  // -------- 2. Fr alle Kanle die genutz werden sollen ----------------------------------------------
  
  for (int i = 0; i < MAX11131_anz + 1; i++)                                     // Fr Anz AD-Wandler ausfhren
  {  
    if(MAX11131_SoP_FD == TRUE)                                                  // Wenn Pseudo oder Single-Ended
    {
      if(MAX11131_SinEnd == TRUE)                                                // Wenn Single-Ended
      {
        befehl = 0x0000;                                                         // Befehlsvariable zurcksetzenZurcksetzen
        befehl = MAX11131_UNIPOLAR;                                              // MAX11131_UNIPOLAR gehe zum Config Register fr Unipolar
        befehl = befehl | !(MAX11131_unipolar_chanel(i));                        // Setze die Kanlle UCHXX auf 0 (ist default 0)
        MAX11131_transmit(befehl);                                               // sSnde nun den Befehl
        __delay_cycles(1000);                                                    // Warte etwas als Sicherheit 
        
        befehl = 0x0000;                                                         // Befehlsvariable zurcksetzenZurcksetzen
        befehl = MAX11131_BIPOLAR;                                               // MAX11131_BIPOLAR gehe aber auch zum Config Register fr Bipolar
        befehl = befehl | !(MAX11131_bipolar_chanel(i));                         // Setze die Kanlle BCHXX auf 0 (ist default 0)   
        MAX11131_transmit(befehl);                                               // Sende nun den Befehl
        __delay_cycles(1000);                                                    // Warte etwas als Sicherheit     
      } // if (SinEnd)
      
      else // Sonst Pseudo-Differenziell
      {
        befehl = 0x0000;                                                         // Befehlsvariable zurcksetzenZurcksetzen
        befehl = MAX11131_UNIPOLAR;                                              // MAX11131_UNIPOLAR gehe zum Config Register fr Unipolar
        befehl = befehl | MAX11131_PDIF_COM;                                     // Setze PDIF_COM fr Pseudo-Differenziell-Modus
        MAX11131_transmit(befehl);                                               // Sende nun den Befehl
        __delay_cycles(1000);                                                    // Warte etwas als Sicherheit                
      } // else (SinEnd)
    } // if (Pseudo oder Single-Ended)
    
    // ----------------------------------------------------------------------
    
    else  // Sonst Voll-Differenziell
    {
      if(MAX11131_UniBip == TRUE)                                                // Wenn Unipolar
      {
        befehl = 0x0000;                                                         // Alten Befehl lschen
        befehl = MAX11131_UNIPOLAR;                                              // Whle Unipolar-Register MAX11131_UNIPOLAR
        befehl = befehl | MAX11131_unipolar_chanel(i);                           // Setze Alle Kanlle UCHXX auf 1
        MAX11131_transmit(befehl);                                               // Sende nun den Befehl
        __delay_cycles(1000);                                                    // Warte etwas als Sicherheit                
      } // if (UniBip)
      
      else // Sonst Bipolar
      {
        befehl = 0x0000;                                                         // Alten Befehl lschen
        befehl = MAX11131_BIPOLAR;                                               // Whle Bipolar-Register MAX11131_BIPOLAR
        befehl = befehl | MAX11131_bipolar_chanel(i);                            // Setze Alle Kanlle BCHXX auf 1
        MAX11131_transmit(befehl);                                               // Sende nun den Befehl
        __delay_cycles(1000);                                                    // Warte etwas als Sicherheit                
        
        if(MAX11131_ran == TRUE)                                                 // Whle Referenz +/-Vref
        {
          befehl = 0x0000;                                                       // Alten Befehl lschen
          befehl = MAX11131_RANGE;                                               // Whle Range-Register aus MAX11131_RANGE
          befehl = befehl | MAX11131_range_chanel(i);                            // MAX11131_RANXX_XX fr jeden ADC auf 1 setzen
          MAX11131_transmit(befehl);                                             // Sende nun den Befehl
          __delay_cycles(1000);                                                  // Warte etwas als Sicherheit                           
        } // if
        
        else // Sonst Referenz +/-Vref/2
        {
          befehl = 0x0000;                                                       // Alten Befehl lschen
          befehl = MAX11131_RANGE;                                               // Whle Range-Register aus MAX11131_RANGE
          befehl = befehl | !MAX11131_range_chanel(i);                           // Setze MAX11131_RANXX_XX 0 (Alles schon Default auf 0)
          MAX11131_transmit(befehl);                                             // Sende nun den Befehl
          __delay_cycles(1000);                                                  // Warte etwas als Sicherheit    
        } // else /ran)
      } // else (UniBip)
    } // else (Voll-Differentiell)
  } // for (Kanalauswahl)
}

//####################################################################################################################################################################################
//                                                                     MAX11131_init()
//
// Initialisiere den MAX11131 indem ich ihm zuerst Konfiguriere und dann Dummy-Werte auslesen
//
//
void MAX11131_init(void)
{
  MAX11131_ADC_conf();                                                           // Setze die ADC-Config register (vorschlag Datenblatt Seite 31)
  for(char i = 0; i < 10; i++) MAX11131_get_ADC(0, 16);                          // Dummy-Messen
}

//####################################################################################################################################################################################
//                                                                     MAX11131_get_ADC_eins()
//
// AD-Wert aus einzelnen Kanal bekommen
//
//
unsigned int MAX11131_get_ADC_eins(char ch)
{
  unsigned int befehl = 0;                                                       // Variable fr den Befehl der dem MAX11131 gesendet werden soll
  static unsigned int adc;                                                       // Array der die 16-Werte des AD-Wandlers zusammenfassen soll

  for(char i = 0; i < 2; i++)                                                    // Mache es fr N-1 Kanle. Beachte ich fordere bei t an und bekomme Antwort bei t+1
  {
    befehl = 0;                                                                  // Lsche zuerst den alten Befehl
    befehl = MAX11131_ADC_MODC;                                                  // Schreibe ins ADC-Mode-Register
    befehl = befehl | MAX11131_SCAN01;                                           // SCAN1 -> Manuelle Messung (nur fr extrenen Clock Mglich)
    befehl = befehl | MAX11131_csel_chanel(ch);                                  // Whle AD-Kanal aus
    befehl = befehl | MAX11131_CHANID;                                           // Whle externe Clock (SCLK)
    adc = MAX11131_transmit(befehl);                                             // Sende Befehl und empfange ADC-Werte als Array
  }  // for
  
  return adc;                                                                    // Gebe AD-Wert zurck
}

//####################################################################################################################################################################################
//                                                                     MAX11131_Aget_ADC()
//
// Siehe dazu "Figure 12/Datenblatt Seite 33". Hier gibt es zu viele mglichkeiten um die Funktion wieder mit TRUE/FALSE bedienenen zu knnen. Whle mr aus was zum Projekt passt. Hier
// Eingestellt sind: Externe Clock, Manuell, Kanalauswahl, No Reset, Power-Mode Normal. Den Kanal/Kanle muss man sich selber ber "anfang" und ende "whlen".
// !!! Wenn ich mehrere Kanle Messe, dann beachte: Ich messe jetzt fr Kanal N und bekomme den Wert von Kanal N-1 zuerst!!
//
// @ start    = Anfangskanal bis
// @ end      = Endkanal
//
// @ rckgabe = Array mit alle AD-Werten unsortiert
//
unsigned int* MAX11131_get_ADC(char start, char end)
{
  unsigned int befehl = 0;                                                       // Variable fr den Befehl der dem MAX11131 gesendet werden soll
  static unsigned int adc[16];                                                   // Array der die 16-Werte des AD-Wandlers zusammenfassen soll
  
  befehl = 0;                                                                    // Lsche zuerst den alten Befehl
  befehl = MAX11131_ADC_MODC;                                                    // Schreibe ins ADC-Mode-Register
  befehl = befehl | MAX11131_SCAN01;                                             // SCAN1 -> Manuelle Messung (nur fr extrenen Clock Mglich)
  befehl = befehl | MAX11131_csel_chanel(0);                                     // Whle AD-Kanal aus
  befehl = befehl | MAX11131_CHANID;                                             // Whle externe Clock (SCLK)
  adc[0] = MAX11131_transmit(befehl);                                            // Sende Befehl und empfange ADC-Werte als Array
  
  for(char i = start + 1; i < end + 1; i++)                                      // Mache es fr N-1 Kanle. Beachte ich fordere bei t an und bekomme Antwort bei t+1
  {
    befehl = 0;                                                                  // Lsche zuerst den alten Befehl
    befehl = MAX11131_ADC_MODC;                                                  // Schreibe ins ADC-Mode-Register
    befehl = befehl | MAX11131_SCAN01;                                           // SCAN1 -> Manuelle Messung (nur fr extrenen Clock Mglich)
    befehl = befehl | MAX11131_csel_chanel(i);                                   // Whle AD-Kanal aus
    befehl = befehl | MAX11131_CHANID;                                           // Whle externe Clock (SCLK)
    adc[i - 1] = MAX11131_transmit(befehl);                                      // Sende Befehl und empfange ADC-Werte als Array
  }  // for
  
  befehl = 0;                                                                    // Lsche zuerst den alten Befehl
  befehl = MAX11131_ADC_MODC;                                                    // Schreibe ins ADC-Mode-Register
  befehl = befehl | MAX11131_SCAN01;                                             // SCAN1 -> Manuelle Messung (nur fr extrenen Clock Mglich)
  befehl = befehl | MAX11131_csel_chanel(0);                                     // Whle AD-Kanal aus
  befehl = befehl | MAX11131_CHANID;                                             // Whle externe Clock (SCLK)
  adc[15] = MAX11131_transmit(befehl);                                           // Sende Befehl und empfange ADC-Werte als Array
  
  return adc;                                                                    // Gebe Array zurck
}

//####################################################################################################################################################################################
//                                                                      MAX11131_mean()
//
// Berechne Mittelwert fr den jeweiligen kanal <ch> mit shift-Division (zeitsparender als normale Division). Achte darauf das <cnt = vielfache von 2> und <pow> die Potenz dazu.
//
unsigned int MAX11131_mean(char ch, int cnt, int pow)
{
  unsigned long int mean = 0;                                                    // Array der die 16-Werte des AD-Wandlers zusammenfassen soll  
  for(int i = 0; i < cnt; i++) mean += MAX11131_get_ADC_eins(ch);                // Addiere Werte auf
  return (mean >> pow);                                                          // Gebe Mittelwert zurck
}