//################################################################################################################################################################################
//
// Headerdatei der Bibliothek "max11131.h"
//
// Ersteller : k.t.evangelos@gmail.com
// Datum     : Juli 2015
// Umgebung  : IAR Embedded Workbench IDE 6.10    
// 
//################################################################################################################################################################################

#ifndef MAX11131_H
#define MAX11131_H

//########################### BIBLIOTHEKEN #######################################################################################################################################

#include <msp430.h> 

//########################### SPI DEFINEs ########################################################################################################################################

#define MAX11131_CS_HIGH    P8OUT |=  BIT0                                       // PIN8.0 auf High ziehen. Muss zuvor als Ausgang gesetzt werden
#define MAX11131_CS_LOW     P8OUT &=~ BIT0                                       // PIN8.0 auf Low ziehen. Muss zuvor als Ausgang gesetzt werden

//######################## MAX11131 REGISTER: ACCESS AND CONTROLL ################################################################################################################

// Folgende Register zur Auswahl:       - MAX11131 REGISTER: ADC MODIFICATION
//                                      - MAX11131 REGISTER: ADC CONFIGURATION
//                                      - MAX11131 REGISTER: UNIPOLAR
//                                      - MAX11131 REGISTER: BIPOLAR
//                                      - MAX11131 REGISTER: RANGE (ONLY FOR BIPOLAR FULLY DIFFERENTIAL)
//                                      - MAX11131 REGISTER: CUSTOM SCAN 0
//                                      - MAX11131 REGISTER: CUSTOM SCAN 1
//                                      - MAX11131 REGISTER: SAMPLE SET
//                                      - MAX11131 REGISTER: DON'T USE

//######################## MAX11131 REGISTER: ADC MODIFICATION ###################################################################################################################

// --------------------- ADC Modification Setup ; Bit 15 -------------------------------------------------------------------------------------------------------------------------

#define MAX11131_ADC_MODC 0x0000                                                 // Bit 15     ; Mode Control: Gehe zum ADC Modification-Register

// -------------------- ADC Scan Controll ; Bits 14 bis 11 -----------------------------------------------------------------------------------------------------------------------

#define MAX11131_SCAN00   0x0000                                                 // Bits 14-11 ; N/A: Operiert im dem letzen gewhlten Modus weiter
#define MAX11131_SCAN01   0x0800                                                 // Bits 14-11 ; Manuell: Der nchste Kanal der Ausgewlt wurde wird in jedem Frame identifiziert. Ergebnis wird im nchsten Frame gelifert
#define MAX11131_SCAN02   0x1000                                                 // Bits 14-11 ; Repeat : Messe kanal N wiederholt (2, 4, 8, 12 oder 16 Ergebnisse f Kanal N). Werte gemittelt. Kanalwahl ber CHSELX
#define MAX11131_SCAN03   0x1800                                                 // Bits 14-11 ; Standart_Int: Messe Kanle 0 bis N. Werte gemittelt. Kanalwahl ber CHSELX. Interner Takt
#define MAX11131_SCAN04   0x2000                                                 // Bits 14-11 ; Standard_Ext: Messe Kanle 0 bis N. Werte gemittelt. Kanalwahl ber CHSELX. Externer Takt
#define MAX11131_SCAN05   0x2800                                                 // Bits 14-11 ; Upper_Int: Messe von N bis hchsten Kanal. FIFO sichert X-Umwandlungen, wobei X = Kanal16 - N ist. Interner Takt
#define MAX11131_SCAN06   0x3000                                                 // Bits 14-11 ; Upper_Ext: Messe von N bis hchsten Kanal. FIFO sichert X-Umwandlungen, wobei X = Kanal16 - N ist. Externer Takt
#define MAX11131_SCAN07   0x3800                                                 // Bits 14-11 ; Custom_Int: Messe vorprogrammierte Kanle in aufsteigedner Lnge. Interner Takt
#define MAX11131_SCAN08   0x4000                                                 // Bits 14-11 ; Custom_Ext: Messe vorprogrammierte Kanle in aufsteigedner Reihenfolge. Externer Takt
#define MAX11131_SCAN09   0x4800                                                 // Bits 14-11 ; SampleSet: Messe vorprogrammiert Kanalfolge mit einer max Lnge von 256. Keine Beschrnkung hinsichtlich der Kanalmuster. Externer Takt
#define MAX11131_SCAN10   0x5000                                                 // Bits 14-11 ; Operiert in dem zuvor ausgewhlten Modus. Ignorieren Daten Bits [10: 0]. ...
#define MAX11131_SCAN11   0x5800                                                 // Bits 14-11 ; ...
#define MAX11131_SCAN12   0x6000                                                 // Bits 14-11 ; ...
#define MAX11131_SCAN13   0x6800                                                 // Bits 14-11 ; ...
#define MAX11131_SCAN14   0x7000                                                 // Bits 14-11 ; ...
#define MAX11131_SCAN15   0x7800                                                 // Bits 14-11 ; .-

// ---------------- Analog Input Channel Select ; Bits 10 bis 7 ------------------------------------------------------------------------------------------------------------------

#define MAX11131_CSEL00   0x0000                                                 // Bits 10-07 ; Auswahl ADC 0
#define MAX11131_CSEL01   0x0080                                                 // Bits 10-07 ; Auswahl ADC 1
#define MAX11131_CSEL02   0x0100                                                 // Bits 10-07 ; Auswahl ADC 2
#define MAX11131_CSEL03   0x0180                                                 // Bits 10-07 ; Auswahl ADC 3
#define MAX11131_CSEL04   0x0200                                                 // Bits 10-07 ; Auswahl ADC 4
#define MAX11131_CSEL05   0x0280                                                 // Bits 10-07 ; Auswahl ADC 5
#define MAX11131_CSEL06   0x0300                                                 // Bits 10-07 ; Auswahl ADC 6
#define MAX11131_CSEL07   0x0380                                                 // Bits 10-07 ; Auswahl ADC 7
#define MAX11131_CSEL08   0x0400                                                 // Bits 10-07 ; Auswahl ADC 8
#define MAX11131_CSEL09   0x0480                                                 // Bits 10-07 ; Auswahl ADC 9
#define MAX11131_CSEL10   0x0500                                                 // Bits 10-07 ; Auswahl ADC 10
#define MAX11131_CSEL11   0x0580                                                 // Bits 10-07 ; Auswahl ADC 11
#define MAX11131_CSEL12   0x0600                                                 // Bits 10-07 ; Auswahl ADC 12
#define MAX11131_CSEL13   0x0680                                                 // Bits 10-07 ; Auswahl ADC 13
#define MAX11131_CSEL14   0x0700                                                 // Bits 10-07 ; Auswahl ADC 14
#define MAX11131_CSEL15   0x0780                                                 // Bits 10-07 ; Auswahl ADC 15

// ---------------- Reset ; Bits 6 bis 5 -----------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_RST00    0x0000                                                 // Bits 06-05 ; Kein Reset
#define MAX11131_RST01    0x0020                                                 // Bits 06-05 ; Resetet nur den FIFO
#define MAX11131_RST02    0x0040                                                 // Bits 06-05 ; Resetet alle Register zu den Default Werten (eingeschloen FIFO)
#define MAX11131_RST03    0x0060                                                 // Bits 06-05 ; Nicht genutzt

// ---------------- Power Management Modes ; Bits 4 bis 3 ------------------------------------------------------------------------------------------------------------------------

#define MAX11131_PM00     0x0000                                                 // Bits 04-03 ; Normal ; Schaltung die ganze Zeit volstndig versorgt
#define MAX11131_PM01     0x0008                                                 // Bits 04-03 ; AutoShut; Nach jeder Conversation schaltet das IC sich ab. Mit !CS wird er nych 2 Zycklen wach
#define MAX11131_PM02     0x0010                                                 // Bits 04-03 ; AusoStand; Schaltet alle ab, auer internem Bias Generator. Mit !CS wird er nych 2 Zycklen wach 
#define MAX11131_PM03     0x0018                                                 // Bits 04-03 ; Nicht genutzt 

// ---------------- Channel ID, SWCNV, UNUSE ; Bits 2 - 0 ------------------------------------------------------------------------------------------------------------------------

#define MAX11131_CHANID   0x0004                                                 // Bit 02     ; Channel ID: Wenn gesetzt ext. Clock, dann hat DOUT das Format: 16Bit, 0-3 Bit= Kanal ; 4 - 15 de Wert (MSB zu erst)
#define MAX11131_SWCNV    0x0001                                                 // Bit 01     ; SWCNV: Wenn gesetzt kommt eine Wandlung mit steigendem !CS und nicht mit pulsieren vom !CSNVST. Nur fr internen Clock Modus
#define MAX11131_UNUSE    0x0000                                                 // Bit 00     ; Wird nich genutzt

//######################## MAX11131 REGISTER: ADC CONFIGURATION ##################################################################################################################

// --------------------  Config Setup ; Bits 15 bis 11 ---------------------------------------------------------------------------------------------------------------------------
                                  
#define MAX11131_ADC_CONF 0x8000                                                 // Bits 04-03 ; Configuration: Gehe zum ADC Konfigurations-Register (siehe "MAX11131 REGISTER: ADC CONFIGURATION")

// ---------------- Reference Selection, Average Bit 10 - 9 ---------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_REFSEL   0x0400                                                 // Bit 10     ; REFSEL: 1: Differenziel ; 0: Single-ended
#define MAX11131_AVGON    0x0200                                                 // Bit 09     ; AVGON: 1: Mitteln An ; 0: Mitteln Aus

// ---------------- Number of Averages ; Bits 8 bis 7 ----------------------------------------------------------------------------------------------------------------------------

#define MAX11131_NAVG04   0x0000                                                 // Bits 08-07 ; AVG 4: AVGON muss zustzlich gesetzt sein. Mittelt 04 Werte. Sonst 1 Wert (AVGON nicht gesetzt).
#define MAX11131_NAVG08   0x0080                                                 // Bits 08-07 ; AVG 8: AVGON muss zustzlich gesetzt sein. Mittelt 08 Werte. Sonst 1 Wert (AVGON nicht gesetzt).
#define MAX11131_NAVG16   0x0100                                                 // Bits 08-07 ; AVG 16: AVGON muss zustzlich gesetzt sein. Mittelt 16 Werte. Sonst 1 Wert (AVGON nicht gesetzt).
#define MAX11131_NAVG32   0x0180                                                 // Bits 08-07 ; AVG 32: AVGON muss zustzlich gesetzt sein. Mittelt 32 Werte. Sonst 1 Wert (AVGON nicht gesetzt).

// ---------------- X scans for N Channel ; Bits 6 bis 5 -------------------------------------------------------------------------------------------------------------------------

#define MAX11131_NSCAN04  0x0000                                                 // Bits 06-05 ; SCAN 4: Messe fr Kanal N und gebe 04 Werte zurck (Nur fr Repeat Mode einsetzbar).
#define MAX11131_NSCAN08  0x0020                                                 // Bits 06-05 ; SCAN 8: Messe fr Kanal N und gebe 08 Werte zurck (Nur fr Repeat Mode einsetzbar).
#define MAX11131_NSCAN16  0x0040                                                 // Bits 06-05 ; SCAN 16: Messe fr Kanal N und gebe 16 Werte zurck (Nur fr Repeat Mode einsetzbar).
#define MAX11131_NSCAN32  0x0060                                                 // Bits 06-05 ; SCAN 32: Messe fr Kanal N und gebe 32 Werte zurck (Nur fr Repeat Mode einsetzbar).

// ---------------- Static Power Down Modes ; Bits 4 bis 3 -----------------------------------------------------------------------------------------------------------------------

#define MAX11131_SPM00    0x0000                                                 // Bits 04-03 ; Normal: Messe fr Kanal N und gebe 04 Werte zurck (Nur fr Repeat Mode einsetzbar).
#define MAX11131_SPM01    0x0008                                                 // Bits 04-03 ; Full Shutdown: Messe fr Kanal N und gebe 08 Werte zurck (Nur fr Repeat Mode einsetzbar).
#define MAX11131_SPM02    0x0010                                                 // Bits 04-03 ; Par. Shutdown: Messe fr Kanal N und gebe 16 Werte zurck (Nur fr Repeat Mode einsetzbar).
#define MAX11131_SPM03    0x0018                                                 // Bits 04-03 ; Wird nicht genutzt

// ---------------- Echo my Configs, Not Used ; Bit 2 - 0 --------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_ECHO     0x0004                                                 // Bits 02    ; Echo: 1: Sendet ber DOUT zum Zeitpunkt n+1 die DIN Eingaben vom Zeitpunkt n ; 0: Kein Echo ber DOUT gesendet
#define MAX11131_DEF0     0x0000                                                 // Bits 01-00 ; Nicht genutzt
#define MAX11131_DEF1     0x0001                                                 // Bits 01-00 ; Nicht genutzt
#define MAX11131_DEF2     0x0002                                                 // Bits 01-00 ; Nicht genutzt
#define MAX11131_DEF3     0x0003                                                 // Bits 01-00 ; Nicht genutzt

//######################## MAX11131 REGISTER: UNIPOLAR ###########################################################################################################################

// ---------------- Unipolar Setup ; Bits 15 bis 11 ------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_UNIPOLAR 0x8800                                                 // Bits 15-11 ; Unipolar: Habe die Auswahl zwischen Pseudo-Differenziel sonst Single-Ended

// -------- Selection Pseudo differential or Single-ended ; Bits 10 bis 2 --------------------------------------------------------------------------------------------------------

#define MAX11131_UCH00_01 0x0400                                                 // Bits 10-02 ; 1: AIN00 und AIN01 Pseudo-Differenz-Umwandlung ; 0: AIN00 und AIN01  Single-Ended
#define MAX11131_UCH02_03 0x0200                                                 // Bits 10-02 ; 1: AIN02 und AIN03 Pseudo-Differenz-Umwandlung ; 0: AIN02 und AIN03  Single-Ended
#define MAX11131_UCH04_05 0x0100                                                 // Bits 10-02 ; 1: AIN04 und AIN05 Pseudo-Differenz-Umwandlung ; 0: AIN04 und AIN05  Single-Ended
#define MAX11131_UCH06_07 0x0080                                                 // Bits 10-02 ; 1: AIN06 und AIN07 Pseudo-Differenz-Umwandlung ; 0: AIN06 und AIN07  Single-Ended
#define MAX11131_UCH08_09 0x0040                                                 // Bits 10-02 ; 1: AIN08 und AIN09 Pseudo-Differenz-Umwandlung ; 0: AIN08 und AIN09  Single-Ended
#define MAX11131_UCH10_11 0x0020                                                 // Bits 10-02 ; 1: AIN10 und AIN11 Pseudo-Differenz-Umwandlung ; 0: AIN10 und AIN11  Single-Ended
#define MAX11131_UCH12_13 0x0010                                                 // Bits 10-02 ; 1: AIN12 und AIN13 Pseudo-Differenz-Umwandlung ; 0: AIN12 und AIN13  Single-Ended
#define MAX11131_UCH14_15 0x0008                                                 // Bits 10-02 ; 1: AIN14 und AIN15 Pseudo-Differenz-Umwandlung ; 0: AIN14 und AIN15  Single-Ended
#define MAX11131_PDIF_COM 0x0004                                                 // Bits 10-02 ; 1: AIN04 bis AIN14 um  als Referenz ein Spannung die uaf AI15 ist zu vergleichen ; 0: Deaktivieren

// ------------------- Not Used ; Bits 1 bis 0 -----------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_UP_NU00  0x0000                                                 // Bits 01-00 ; Nicht genutzt
#define MAX11131_UP_NU01  0x0001                                                 // Bits 01-00 ; Nicht genutzt
#define MAX11131_UP_NU02  0x0002                                                 // Bits 01-00 ; Nicht genutzt
#define MAX11131_UP_NU03  0x0003                                                 // Bits 01-00 ; Nicht genutzt

//######################## MAX11131 REGISTER: BIPOLAR ############################################################################################################################

// ---------------- Bipolar Setup ; Bits 15 bis 11 -------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_BIPOLAR  0x9000                                                 // Bits 15-11 ; Bipolar: Kann hier auswhlen ob Differentiel oder Unipolar (Pseudo oder Single) gemessen werden soll

// -------- Selection Pseudo differential or Single-ended ; Bits 10 bis 3 --------------------------------------------------------------------------------------------------------

#define MAX11131_BCH00_01 0x0400                                                 // Bit 10     ; 1: AIN00 und AIN01 Differenz-Umwandlung ; 0: AIN00 und AIN01  Single-Ended
#define MAX11131_BCH02_03 0x0200                                                 // Bit 09     ; 1: AIN02 und AIN03 Differenz-Umwandlung ; 0: AIN02 und AIN03  Single-Ended
#define MAX11131_BCH04_05 0x0100                                                 // Bit 08     ; 1: AIN04 und AIN05 Differenz-Umwandlung ; 0: AIN04 und AIN05  Single-Ended
#define MAX11131_BCH06_07 0x0080                                                 // Bit 07     ; 1: AIN06 und AIN07 Differenz-Umwandlung ; 0: AIN06 und AIN07  Single-Ended
#define MAX11131_BCH08_09 0x0040                                                 // Bit 06     ; 1: AIN08 und AIN09 Differenz-Umwandlung ; 0: AIN08 und AIN09  Single-Ended
#define MAX11131_BCH10_11 0x0020                                                 // Bit 05     ; 1: AIN10 und AIN11 Differenz-Umwandlung ; 0: AIN10 und AIN11  Single-Ended
#define MAX11131_BCH12_13 0x0010                                                 // Bit 04     ; 1: AIN12 und AIN13 Differenz-Umwandlung ; 0: AIN12 und AIN13  Single-Ended
#define MAX11131_BCH14_15 0x0008                                                 // Bit 03     ; 1: AIN14 und AIN15 Differenz-Umwandlung ; 0: AIN14 und AIN15  Single-Ended

// ------------------- Not Used ; Bits 2 bis 0 -----------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_BP_NU00  0x0000                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_BP_NU01  0x0001                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_BP_NU02  0x0002                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_BP_NU03  0x0003                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_BP_NU04  0x0004                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_BP_NU05  0x0005                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_BP_NU06  0x0006                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_BP_NU07  0x0007                                                 // Bits 02-00 ; Nicht genutzt

//######################## MAX11131 REGISTER: RANGE (ONLY FOR BIPOLAR FULLY DIFFERENTIAL) ########################################################################################

// ---------------- Range Setup ; Bits 15 bis 11 ---------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_RANGE    0x9800                                                 // Bits 02-00 ; Range: Whle die Refernzpins fr Referenzspannung Vref und Vref/2

// ---------------- Range ; Bits 10 - 03 -----------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_RAN00_01 0x0400                                                 // Bit 10     ; 0: AIN0/1: +-VREF+/2 ; 1: AIN0/1: +-VREF+
#define MAX11131_RAN02_03 0x0200                                                 // Bit 09     ; 0: AIN2/3: +-VREF+/2 ; 1: AIN2/3: +-VREF+
#define MAX11131_RAN04_05 0x0100                                                 // Bit 08     ; 0: AIN4/5: +-VREF+/2 ; 1: AIN4/5: +-VREF+
#define MAX11131_RAN06_07 0x0080                                                 // Bit 07     ; 0: AIN6/7: +-VREF+/2 ; 1: AIN6/7: +-VREF+
#define MAX11131_RAN08_09 0x0040                                                 // Bit 06     ; 0: AIN8/9: +-VREF+/2 ; 1: AIN8/9: +-VREF+
#define MAX11131_RAN10_11 0x0020                                                 // Bit 05     ; 0: AIN10/11: +-VREF+/2 ; 1: AIN10/11: +-VREF+
#define MAX11131_RAN12_13 0x0010                                                 // Bit 04     ; 0: AIN12/13: +-VREF+/2 ; 1: AIN12/13: +-VREF+
#define MAX11131_RAN14_15 0x0008                                                 // Bit 03     ; 0: AIN14/15: +-VREF+/2 ; 1: AIN14/15: +-VREF+

// ---------------- Range ; Bits 2 bis 0 -----------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_RAN_NU00 0x0000                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_RAN_NU01 0x0001                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_RAN_NU02 0x0002                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_RAN_NU03 0x0003                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_RAN_NU04 0x0004                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_RAN_NU05 0x0005                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_RAN_NU06 0x0006                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_RAN_NU07 0x0007                                                 // Bits 02-00 ; Nicht genutzt

//######################## MAX11131 REGISTER: CUSTOM SCAN 0 ######################################################################################################################

// ---------------- Range Setup ; Bits 15 bis 11 ---------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_CUS_SCA0 0xA000                                                 // Bits 15-11 ; Whle von den AD-Wandlern 15 bis 8 welche ich ntzen mchte

// ---------------- Range ; Bit 10 bis 3 -----------------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_CHSCAN15 0x0400                                                 // Bit 10     ; 1: Nutze AIN15 ; 0: Lasse AIN15 weg
#define MAX11131_CHSCAN14 0x0200                                                 // Bit 09     ; 1: Nutze AIN14 ; 0: Lasse AIN14 weg
#define MAX11131_CHSCAN13 0x0100                                                 // Bit 08     ; 1: Nutze AIN13 ; 0: Lasse AIN13 weg
#define MAX11131_CHSCAN12 0x0080                                                 // Bit 07     ; 1: Nutze AIN12 ; 0: Lasse AIN12 weg
#define MAX11131_CHSCAN11 0x0040                                                 // Bit 06     ; 1: Nutze AIN11 ; 0: Lasse AIN11 weg
#define MAX11131_CHSCAN10 0x0020                                                 // Bit 05     ; 1: Nutze AIN10 ; 0: Lasse AIN10 weg
#define MAX11131_CHSCAN09 0x0010                                                 // Bit 04     ; 1: Nutze AIN09 ; 0: Lasse AIN09 weg
#define MAX11131_CHSCAN08 0x0008                                                 // Bit 03     ; 1: Nutze AIN08 ; 0: Lasse AIN08 weg

// ---------------- Range ; Bit 2 bis 0 ------------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_CS0_NU00 0x0000                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS0_NU01 0x0001                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS0_NU02 0x0002                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS0_NU03 0x0003                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS0_NU04 0x0004                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS0_NU05 0x0005                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS0_NU06 0x0006                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS0_NU07 0x0007                                                 // Bits 02-00 ; Nicht genutzt

//######################## MAX11131 REGISTER: CUSTOM SCAN 1 ######################################################################################################################

// ---------------- Range Setup ; Bits 15 bis 11 ---------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_CUS_SCA1 0xA800                                                 // Bits 15-11 ; Whle von den AD-Wandlern 7 bis 0 welche ich ntzen mchte

// ---------------- Range ; Bits 10 bis 3 -----------------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_CHSCAN07 0x0400                                                 // Bit 10     ; 1: Nutze AIN07 ; 0: Lasse AIN07 weg
#define MAX11131_CHSCAN06 0x0200                                                 // Bit 09     ; 1: Nutze AIN06 ; 0: Lasse AIN06 weg
#define MAX11131_CHSCAN05 0x0100                                                 // Bit 08     ; 1: Nutze AIN05 ; 0: Lasse AIN05 weg
#define MAX11131_CHSCAN04 0x0080                                                 // Bit 07     ; 1: Nutze AIN04 ; 0: Lasse AIN04 weg
#define MAX11131_CHSCAN03 0x0040                                                 // Bit 06     ; 1: Nutze AIN03 ; 0: Lasse AIN03 weg
#define MAX11131_CHSCAN02 0x0020                                                 // Bit 05     ; 1: Nutze AIN02 ; 0: Lasse AIN02 weg
#define MAX11131_CHSCAN01 0x0010                                                 // Bit 04     ; 1: Nutze AIN01 ; 0: Lasse AIN01 weg
#define MAX11131_CHSCAN00 0x0008                                                 // Bit 03     ; 1: Nutze AIN00 ; 0: Lasse AIN00 weg

// ---------------- Not Used ; Bit 2 bis 0 ------------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_CS1_NU00 0x0000                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS1_NU01 0x0001                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS1_NU02 0x0002                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS1_NU03 0x0003                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS1_NU04 0x0004                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS1_NU05 0x0005                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS1_NU06 0x0006                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_CS1_NU07 0x0007                                                 // Bits 02-00 ; Nicht genutzt

//######################## MAX11131 REGISTER: SAMPLE SET #########################################################################################################################

// ---------------- Range Setup ; Bits 15 bis 11 ---------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_SAMP_SET 0xB000                                                 // Bits 15-11 ; SampleSet: Kann auswhlen wie viele Sample der AD-Wandler aufnehmen soll

// ---------------- Length of Conversions ; Bit 10 bis 3 ------------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_SEQ_LENG 0x0000                                                 // Bits 10-03 ; 0x07F8: 256 Umwandlung max ; 0: 1 Umwandlung. Alles dazwischen auswlbar Length = SEQ_LENG+1 (Nur Bit 10-3)

// ---------------- Not Used ; Bit 2 bis 0 ------------------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_SEQ_NU00 0x0000                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_SEQ_NU01 0x0001                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_SEQ_NU02 0x0002                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_SEQ_NU03 0x0003                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_SEQ_NU04 0x0004                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_SEQ_NU05 0x0005                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_SEQ_NU06 0x0006                                                 // Bits 02-00 ; Nicht genutzt
#define MAX11131_SEQ_NU07 0x0007                                                 // Bits 02-00 ; Nicht genutzt

//######################## MAX11131 REGISTER: DON'T USE ##########################################################################################################################

// ---------------- Range Setup ; Bits 15 bis 11 ---------------------------------------------------------------------------------------------------------------------------------

#define MAX11131_DONT_USE 0xF800                                                 // Bits 15-11 ; Don't use   

//###################### AD-AUSWAHL ##############################################################################################################################################

#define MAX11131_RefSel TRUE                                                     // Siehe Funktion MAX11131_ADC_conf(), was steht fr TRUE, was fr FALSE
#define MAX11131_SoP_FD TRUE                                                     // ...
#define MAX11131_SinEnd TRUE                                                     // ...
#define MAX11131_UniBip TRUE                                                     // ...
#define MAX11131_ran FALSE                                                       // .-
#define MAX11131_anz 7                                                           // Siehe Funktion MAX11131_ADC_conf(). Zahlen zwische  bis  mglich

#define TRUE 0                                                                   // Meine bool Variablen ...
#define FALSE 1                                                                  // .-

//###################### PROTOTYPEN ##############################################################################################################################################

void MAX11131_SPI_init(void);                                                    // Initialisiert die SPI-Schnittstelle fr Kanal UCA1 des MSP430F5359
unsigned char MAX11131_SPI_transmit(unsigned char data);                         // Senden und empfangen ber SPI ber Kanal UCA1 des MSP430F5359

unsigned int MAX11131_transmit(unsigned int command);                            // Sendet und liest vom MAX11131 AD-Wandler
//unsigned int MAX11131_bipolar_chanel(char k);               INLINE             // Funktion mit Switch-Anweisung zur auswahl des Bipolar-Kanals (nur intern gebraucht)
//unsigned int MAX11131_unipolar_chanel(char k);              INLINE             // Funktion mit Switch-Anweisung zur auswahl des Unipolar-Kanals (nur intern gebraucht) 
//unsigned int MAX11131_range_chanel(char k);                 INLINE             // Funktion mit Switch-Anweisung zur auswahl des Range-Kanals (nur intern gebraucht) 
//unsigned int MAX11131_csel_chanel(char k);                  INLINE             // Funktion mit Switch-Anweisung zur auswahl der AD-Kanle (nur intern gebraucht)
void MAX11131_Echo_aktiv (char status);                                          // Aktiviert die Echo-Ausgabe des MAX11131
void MAX11131_test (void);                                                       // Teste den MAX11131, als resultat sollte 0x8380 kommen
void MAX11131_ADC_conf(void);                                                    // Konfiguriere den MAX11131, siehe "Figure 11/Datenblatt Seite 32"
void MAX11131_init(void);                                                        // Initialisiere den MAX11131 indem ich ihm zuerst Konfiguriere und dann Dummy-Werte auslesen 
unsigned int MAX11131_get_ADC_eins(char ch);                                     // AD-Wert aus einzelnen Kanal bekommen
unsigned int* MAX11131_get_ADC(char start, char end);                            // Bekomme AD-Wert vom MAX11131 zurck als Array
unsigned int MAX11131_mean(char ch, int cnt, int pow);                           // Berechne Mittelwert fr den jeweiligen kanal <ch> mit shift-Division


#endif